cluster

Function cluster 

pub fn cluster(markers: &[LonLat], zoom: u8, cell_px: f64) -> Vec<Cluster>
Cluster markers with a grid of cell_px pixels at zoom.

Markers falling into the same grid cell are merged. Single-marker cells are returned as clusters with count == 1.