pub fn nav_progress(route: &[LonLat], user: LonLat) -> Option<NavProgress>Expand description
Compute navigation progress given the user’s current position.
Finds the nearest route point ahead and reports distance done/left.
pub fn nav_progress(route: &[LonLat], user: LonLat) -> Option<NavProgress>Compute navigation progress given the user’s current position.
Finds the nearest route point ahead and reports distance done/left.